import{s as Li,n as Mi,o as Pi}from"../chunks/scheduler.7bc62968.js";import{S as Hi,i as Di,g as l,s,r as pe,A as $i,h as o,f as i,c as a,j as Ci,u as he,x as r,k as _i,y as ki,a as n,v as me,d as ge,t as ce,w as ve}from"../chunks/index.2f8492b0.js";import{H as xe}from"../chunks/Heading.14fb2476.js";function Ii(Mt){let f,be,we,Te,u,Ce,d,Pt=`Imagine trying to train a model for tumor segmentation. As it’s hard to gather data for medical imaging, it’d be really difficult for the model to converge.
Ideally, we expect to have at least enough data to build a simple baseline, but what if you have just a few samples? Synthetic data generation methods try to solve this dilemma, and now we have many more options with the boom of generative models!`,_e,p,Ht='As you’ve seen in the previous sections, it is possible to use generative models such as DCGAN to generate synthetic images. In this section, we will focus on diffusion models using <a href="https://huggingface.co/docs/diffusers/index" rel="nofollow">diffusers</a>!',Le,h,Me,m,Dt="Diffusion models are generative models that gained significant popularity in recent years, thanks to their capabilities to produce high-quality images. Nowadays, they’re widely used in image, video, and text synthesis.",Pe,g,$t="A diffusion model works by learning to denoise random Gaussian noise step-by-step. The training process requires adding Gaussian noise to the input samples and letting the model learn denoising.",He,c,kt='Diffusion models are generally conditioned to a kind of input besides the data distribution, such as text prompts, images or even audio. Additionally, it’s also possible to <a href="https://huggingface.co/docs/diffusers/training/unconditional_training" rel="nofollow">build an unconditional generator</a>.',De,v,It="There are many underlying concepts behind the model’s inner workings but the simplified version is similar to this:",$e,x,St="Firstly, the model adds noise to the input and processes it.",ke,w,At='<img src="https://huggingface.co/datasets/hf-vision/course-assets/resolve/main/synthetic-data-creation-diffusion-models/noising.jpg?download=true" alt="noising"/>',Ie,y,qt="Then the model learns to denoise the given data distribution.",Se,b,jt='<img src="https://huggingface.co/datasets/hf-vision/course-assets/resolve/main/synthetic-data-creation-diffusion-models/denoising.jpg?download=true" alt="denoising"/>',Ae,T,Gt="We won’t dive deep into the theory, but understanding how a diffusion model works will come really handy when we need to pick a technique to generate synthetic data for our use case.",qe,C,je,_,zt="Essentially, the way Stable Diffusion (SD) works is the same as we mentioned above. It uses three main components that help it to produce high-quality images.",Ge,L,Et="<li><p><strong>The diffusion process:</strong> The input is processed multiple times to generate useful information about the image. The “usefulness” is learned while training the model.</p></li> <li><p><strong>Image encoder and decoder model:</strong> Lets the model compress images from pixel space to a smaller dimensional space, abstracting meaningless information while increasing performance.</p></li> <li><p><strong>Optional conditional encoder:</strong> This component is used to condition to generation process on an input. This extra input can be text prompts, images, audio, and other representations. Originally, it was a text encoder.</p></li>",ze,M,Rt=`So while the general workflow looks like this:
<img src="https://huggingface.co/datasets/hf-vision/course-assets/resolve/main/synthetic-data-creation-diffusion-models/general-workflow.png?download=true" alt="general stable diffusion workflow"/>`,Ee,P,Ut=`Originally we used a text encoder to condition the model on our prompts:
<img src="https://huggingface.co/datasets/hf-vision/course-assets/resolve/main/synthetic-data-creation-diffusion-models/stable-diffusion-workflow.png?download=true" alt="original stable diffusion workflow"/>`,Re,H,Bt='This short overview is just the tip of the iceberg! If you wish to dive deep into the theory behind stable diffusion (or diffusion models), you can out the <a href="#further-reading-about-stable-diffusion">further reading section</a>!',Ue,D,Ft='<a href="https://huggingface.co/docs/diffusers/index" rel="nofollow">diffusers</a> provide us ready to use pipelines for different tasks, such as:',Be,$,Ot='<thead><tr><th>Task</th> <th>Description</th> <th>Pipeline</th></tr></thead> <tbody><tr><td>Unconditional Image Generation</td> <td>generate an image from Gaussian noise</td> <td><a href="https://huggingface.co/docs/diffusers/using-diffusers/unconditional_image_generation" rel="nofollow">unconditional_image_generation</a></td></tr> <tr><td>Text-Guided Image Generation</td> <td>generate an image given a text prompt</td> <td><a href="https://huggingface.co/docs/diffusers/using-diffusers/conditional_image_generation" rel="nofollow">conditional_image_generation</a></td></tr> <tr><td>Text-Guided Image-to-Image Translation</td> <td>adapt an image guided by a text prompt</td> <td><a href="https://huggingface.co/docs/diffusers/using-diffusers/img2img" rel="nofollow">img2img</a></td></tr> <tr><td>Text-Guided Image-Inpainting</td> <td>fill the masked part of an image given the image, the mask and a text prompt</td> <td><a href="https://huggingface.co/docs/diffusers/using-diffusers/inpaint" rel="nofollow">inpaint</a></td></tr> <tr><td>Text-Guided Depth-to-Image Translation</td> <td>adapt parts of an image guided by a text prompt while preserving structure via depth estimation</td> <td><a href="https://huggingface.co/docs/diffusers/using-diffusers/depth2img" rel="nofollow">depth2img</a></td></tr></tbody>',Fe,k,Vt='There’s also a complete list of supported tasks that you can find from the <a href="https://huggingface.co/docs/diffusers/api/pipelines/overview#diffusers-summary" rel="nofollow">Diffusers Summary</a> table.',Oe,I,Nt="This means we have many tools under our belt to generate synthetic data!",Ve,S,Ne,A,Wt="There are generally three cases for needing synthetic data,",We,q,Yt="<strong>Extending an existing dataset:</strong>",Ye,j,Xt='<li><strong>There are not enough samples:</strong> A nice example is a medical imaging dataset such as <a href="https://www.mammoimage.org/databases/" rel="nofollow">DDSM</a> (Digital Database for Screening Mammography, ~2500 samples), a small amount of samples makes it harder to build a model for further analysis. It’s also rather expensive to build such medical imaging datasets.</li>',Xe,G,Jt="<strong>Creating a Dataset from Scratch</strong>:",Je,z,Kt="<li><strong>There aren’t any samples at all:</strong> Let’s assume that you want to build a weapon detection system on top of CCTV video streams. But there aren’t any samples for the specific weapon you want to detect, you can use similar observations in different settings to apply style transfer to make them look like CCTV streams!</li>",Ke,E,Qt="<strong>Preserving Privacy</strong>:",Qe,R,Zt="<li>Hospitals collect huge amounts of data on patients, surveillance cameras capture raw information about individuals’ faces and activities, and all of these introduce a potential infringe on privacy. We can use diffusion models to generate privacy-preserving datasets to develop our solutions, without giving up on anyone’s privacy rights.</li>",Ze,U,ei='There are different methods for us to utilize a text-to-image diffusion model to generate customized outputs. For example, by simply utilizing the pre-trained diffusion model (such as <a href="https://huggingface.co/docs/diffusers/api/pipelines/stable_diffusion/stable_diffusion_xl" rel="nofollow">Stable Diffusion XL</a>), you can try to construct a nice prompt to generate images. But the quality of the generated images may not be consistent and it might be really difficult to construct such a prompt for your specific use case.',et,B,ti="You will usually be required to change some parts of the model to generate the personalized output you want, here are a few techniques that you can use for that:",tt,F,ii='<strong>Training with <a href="https://huggingface.co/docs/diffusers/main/en/training/text_inversion" rel="nofollow">Textual Inversion</a>:</strong>',it,O,ni='<img src="https://huggingface.co/datasets/hf-vision/course-assets/resolve/main/synthetic-data-creation-diffusion-models/textual_inversion.png?download=true" alt="textual-inversion"/>',nt,V,si="Textual inversion is a technique that works by interfering with the text embeddings in the model’s architecture. You can add a new token to the vocabulary and then fine-tune the embeddings using a few examples.",st,N,ai="By providing samples corresponding to the new token, we try to optimize the embeddings to capture the characteristics of the object.",at,W,li='<strong>Training a <a href="https://huggingface.co/docs/diffusers/main/en/training/lora?installation=PyTorch" rel="nofollow">LoRA (Low-Rank Adaptation)</a> model:</strong>',lt,Y,oi="LoRA has targeted the problem of fine-tuning LLMs. It represents the weight updates with two smaller update matrices through low-rank decomposition, which has substantially less amount of parameters. Then these matrices can be trained to adapt the new data!",ot,X,ri="The base model’s weights remain frozen in the whole process, so we just train the new update matrices. Then lastly, the adapted weights are combined with the original weights.",rt,J,fi="This means training LoRA is essentially much faster than full model fine-tuning! As an important note, it’s also possible to combine LoRA with other techniques since it can be added on top of the model itself.",ft,K,ui='<strong>Training with <a href="https://huggingface.co/docs/diffusers/main/en/training/dreambooth" rel="nofollow">DreamBooth</a>:</strong>',ut,Q,di='<img src="https://huggingface.co/datasets/hf-vision/course-assets/resolve/main/synthetic-data-creation-diffusion-models/dreambooth.png?download=true" alt="dreambooth"/>',dt,Z,pi="DreamBooth is a technique to fine-tune the model to personalize the outputs. Given a few images of a subject, it lets you fine-tune a pre-trained text-to-image model. The main idea is to associate a unique identifier with that specific subject.",pt,ee,hi="For training, we use the tokens in the vocabulary and build a dataset using preferably a rare-token identifier. Because if you choose a rather common identifier, the model would also have to learn to disentangle from their original meaning.",ht,te,mi="In the original paper, authors find the rare tokens in the vocabulary and then choose identifiers from those. This reduces the risk of an identifier having a strong prior. It is also stated that the best results were achieved by fine-tuning all the layers of the model.",mt,ie,gi='<strong>Training with <a href="https://huggingface.co/docs/diffusers/main/en/training/custom_diffusion" rel="nofollow">Custom Diffusion</a>:</strong>',gt,ne,ci='<img src="https://huggingface.co/datasets/hf-vision/course-assets/resolve/main/synthetic-data-creation-diffusion-models/custom_diffusion.png?download=true" alt="custom diffusion"/>',ct,se,vi="Custom Diffusion is a really powerful technique to personalize the model. It requires just a few samples like the previously mentioned methods, but its power lies in being able to learn multiple concepts at the same time!",vt,ae,xi="It works by training just a part of the diffusion process and the text encoder we mentioned above, meaning that there are fewer parameters to optimize. Thus, this method also enables fast fine-tuning!",xt,le,wt,oe,wi="There are many unique cases where diffusion models are used to generate synthetic datasets!",yt,re,yi="Find them below.",bt,fe,bi='<li><a href="https://arxiv.org/abs/2306.09762" rel="nofollow">Apple Images for Apple Detection in Orchards</a></li> <li><a href="https://arxiv.org/abs/2310.16794" rel="nofollow">Automatically Labeled Polyp Images for Medical Image Segmentation</a></li> <li><a href="https://www.nature.com/articles/s41598-023-34341-2.pdf" rel="nofollow">3D Medical Image Generation with DDPMs</a></li> <li><a href="https://ieeexplore.ieee.org/document/10281144" rel="nofollow">Generating Transmission Line Images with DDPM</a></li> <li><a href="https://ieeexplore.ieee.org/document/10195076" rel="nofollow">Synthetic Aerial Dataset for Unmanned Aerial Vehicle Detection</a></li> <li><a href="https://arxiv.org/pdf/2302.13861.pdf" rel="nofollow">Differentially Private Diffusion Models for Privacy-preserving Synthetic Image Generation</a></li>',Tt,ue,Ct,de,Ti='<li><a href="https://jalammar.github.io/illustrated-stable-diffusion/" rel="nofollow">The Illustrated Stable Diffusion</a></li> <li><a href="https://poloclub.github.io/diffusion-explainer/" rel="nofollow">Diffusion Explainer: Stable Diffusion Explained with Visualization</a></li> <li><a href="https://www.assemblyai.com/blog/diffusion-models-for-machine-learning-introduction/" rel="nofollow">Introduction to Diffusion Models</a></li> <li><a href="https://course.fast.ai/Lessons/lesson9.html" rel="nofollow">FastAI, Practical Deep Learning for Coders - Lesson 9: Stable Diffusion</a></li> <li><a href="https://arxiv.org/abs/2112.10752" rel="nofollow">Original paper</a></li>',_t,ye,Lt;return u=new xe({props:{title:"Synthetic Data Generation with Diffusion Models",local:"synthetic-data-generation-with-diffusion-models",headingTag:"h1"}}),h=new xe({props:{title:"Recap of the Diffusion Models",local:"recap-of-the-diffusion-models",headingTag:"h2"}}),C=new xe({props:{title:"Text-To-Image Diffusion Model: Stable Diffusion",local:"text-to-image-diffusion-model-stable-diffusion",headingTag:"h2"}}),S=new xe({props:{title:"Approaches to Synthetic Data Generation",local:"approaches-to-synthetic-data-generation",headingTag:"h2"}}),le=new xe({props:{title:"Real-world Examples of Using Diffusion Models for Dataset Generation",local:"real-world-examples-of-using-diffusion-models-for-dataset-generation",headingTag:"h2"}}),ue=new xe({props:{title:"Further reading about Stable Diffusion",local:"further-reading-about-stable-diffusion",headingTag:"h2"}}),{c(){f=l("meta"),be=s(),we=l("p"),Te=s(),pe(u.$$.fragment),Ce=s(),d=l("p"),d.textContent=Pt,_e=s(),p=l("p"),p.innerHTML=Ht,Le=s(),pe(h.$$.fragment),Me=s(),m=l("p"),m.textContent=Dt,Pe=s(),g=l("p"),g.textContent=$t,He=s(),c=l("p"),c.innerHTML=kt,De=s(),v=l("p"),v.textContent=It,$e=s(),x=l("p"),x.textContent=St,ke=s(),w=l("p"),w.innerHTML=At,Ie=s(),y=l("p"),y.textContent=qt,Se=s(),b=l("p"),b.innerHTML=jt,Ae=s(),T=l("p"),T.textContent=Gt,qe=s(),pe(C.$$.fragment),je=s(),_=l("p"),_.textContent=zt,Ge=s(),L=l("ol"),L.innerHTML=Et,ze=s(),M=l("p"),M.innerHTML=Rt,Ee=s(),P=l("p"),P.innerHTML=Ut,Re=s(),H=l("p"),H.innerHTML=Bt,Ue=s(),D=l("p"),D.innerHTML=Ft,Be=s(),$=l("table"),$.innerHTML=Ot,Fe=s(),k=l("p"),k.innerHTML=Vt,Oe=s(),I=l("p"),I.textContent=Nt,Ve=s(),pe(S.$$.fragment),Ne=s(),A=l("p"),A.textContent=Wt,We=s(),q=l("p"),q.innerHTML=Yt,Ye=s(),j=l("ul"),j.innerHTML=Xt,Xe=s(),G=l("p"),G.innerHTML=Jt,Je=s(),z=l("ul"),z.innerHTML=Kt,Ke=s(),E=l("p"),E.innerHTML=Qt,Qe=s(),R=l("ul"),R.innerHTML=Zt,Ze=s(),U=l("p"),U.innerHTML=ei,et=s(),B=l("p"),B.textContent=ti,tt=s(),F=l("p"),F.innerHTML=ii,it=s(),O=l("p"),O.innerHTML=ni,nt=s(),V=l("p"),V.textContent=si,st=s(),N=l("p"),N.textContent=ai,at=s(),W=l("p"),W.innerHTML=li,lt=s(),Y=l("p"),Y.textContent=oi,ot=s(),X=l("p"),X.textContent=ri,rt=s(),J=l("p"),J.textContent=fi,ft=s(),K=l("p"),K.innerHTML=ui,ut=s(),Q=l("p"),Q.innerHTML=di,dt=s(),Z=l("p"),Z.textContent=pi,pt=s(),ee=l("p"),ee.textContent=hi,ht=s(),te=l("p"),te.textContent=mi,mt=s(),ie=l("p"),ie.innerHTML=gi,gt=s(),ne=l("p"),ne.innerHTML=ci,ct=s(),se=l("p"),se.textContent=vi,vt=s(),ae=l("p"),ae.textContent=xi,xt=s(),pe(le.$$.fragment),wt=s(),oe=l("p"),oe.textContent=wi,yt=s(),re=l("p"),re.textContent=yi,bt=s(),fe=l("ul"),fe.innerHTML=bi,Tt=s(),pe(ue.$$.fragment),Ct=s(),de=l("ul"),de.innerHTML=Ti,_t=s(),ye=l("p"),this.h()},l(e){const t=$i("svelte-u9bgzb",document.head);f=o(t,"META",{name:!0,content:!0}),t.forEach(i),be=a(e),we=o(e,"P",{}),Ci(we).forEach(i),Te=a(e),he(u.$$.fragment,e),Ce=a(e),d=o(e,"P",{"data-svelte-h":!0}),r(d)!=="svelte-1au98lo"&&(d.textContent=Pt),_e=a(e),p=o(e,"P",{"data-svelte-h":!0}),r(p)!=="svelte-1797j0h"&&(p.innerHTML=Ht),Le=a(e),he(h.$$.fragment,e),Me=a(e),m=o(e,"P",{"data-svelte-h":!0}),r(m)!=="svelte-113ubsd"&&(m.textContent=Dt),Pe=a(e),g=o(e,"P",{"data-svelte-h":!0}),r(g)!=="svelte-1om52vs"&&(g.textContent=$t),He=a(e),c=o(e,"P",{"data-svelte-h":!0}),r(c)!=="svelte-53u6be"&&(c.innerHTML=kt),De=a(e),v=o(e,"P",{"data-svelte-h":!0}),r(v)!=="svelte-kyky19"&&(v.textContent=It),$e=a(e),x=o(e,"P",{"data-svelte-h":!0}),r(x)!=="svelte-1oamlss"&&(x.textContent=St),ke=a(e),w=o(e,"P",{"data-svelte-h":!0}),r(w)!=="svelte-jtkwam"&&(w.innerHTML=At),Ie=a(e),y=o(e,"P",{"data-svelte-h":!0}),r(y)!=="svelte-xfuqp4"&&(y.textContent=qt),Se=a(e),b=o(e,"P",{"data-svelte-h":!0}),r(b)!=="svelte-16i1xv2"&&(b.innerHTML=jt),Ae=a(e),T=o(e,"P",{"data-svelte-h":!0}),r(T)!=="svelte-6nn3z8"&&(T.textContent=Gt),qe=a(e),he(C.$$.fragment,e),je=a(e),_=o(e,"P",{"data-svelte-h":!0}),r(_)!=="svelte-1gdezvg"&&(_.textContent=zt),Ge=a(e),L=o(e,"OL",{"data-svelte-h":!0}),r(L)!=="svelte-y5tn4l"&&(L.innerHTML=Et),ze=a(e),M=o(e,"P",{"data-svelte-h":!0}),r(M)!=="svelte-16bx26v"&&(M.innerHTML=Rt),Ee=a(e),P=o(e,"P",{"data-svelte-h":!0}),r(P)!=="svelte-wcyk00"&&(P.innerHTML=Ut),Re=a(e),H=o(e,"P",{"data-svelte-h":!0}),r(H)!=="svelte-6679cp"&&(H.innerHTML=Bt),Ue=a(e),D=o(e,"P",{"data-svelte-h":!0}),r(D)!=="svelte-1ngkqqa"&&(D.innerHTML=Ft),Be=a(e),$=o(e,"TABLE",{"data-svelte-h":!0}),r($)!=="svelte-3kghyd"&&($.innerHTML=Ot),Fe=a(e),k=o(e,"P",{"data-svelte-h":!0}),r(k)!=="svelte-10xco5v"&&(k.innerHTML=Vt),Oe=a(e),I=o(e,"P",{"data-svelte-h":!0}),r(I)!=="svelte-1vypxyz"&&(I.textContent=Nt),Ve=a(e),he(S.$$.fragment,e),Ne=a(e),A=o(e,"P",{"data-svelte-h":!0}),r(A)!=="svelte-mbqjoq"&&(A.textContent=Wt),We=a(e),q=o(e,"P",{"data-svelte-h":!0}),r(q)!=="svelte-3vd95n"&&(q.innerHTML=Yt),Ye=a(e),j=o(e,"UL",{"data-svelte-h":!0}),r(j)!=="svelte-10y5o6i"&&(j.innerHTML=Xt),Xe=a(e),G=o(e,"P",{"data-svelte-h":!0}),r(G)!=="svelte-1qg0jtt"&&(G.innerHTML=Jt),Je=a(e),z=o(e,"UL",{"data-svelte-h":!0}),r(z)!=="svelte-1nn9s3v"&&(z.innerHTML=Kt),Ke=a(e),E=o(e,"P",{"data-svelte-h":!0}),r(E)!=="svelte-r3j44y"&&(E.innerHTML=Qt),Qe=a(e),R=o(e,"UL",{"data-svelte-h":!0}),r(R)!=="svelte-z3w7lm"&&(R.innerHTML=Zt),Ze=a(e),U=o(e,"P",{"data-svelte-h":!0}),r(U)!=="svelte-1llf13q"&&(U.innerHTML=ei),et=a(e),B=o(e,"P",{"data-svelte-h":!0}),r(B)!=="svelte-18kjuzm"&&(B.textContent=ti),tt=a(e),F=o(e,"P",{"data-svelte-h":!0}),r(F)!=="svelte-1l38shg"&&(F.innerHTML=ii),it=a(e),O=o(e,"P",{"data-svelte-h":!0}),r(O)!=="svelte-k57a0"&&(O.innerHTML=ni),nt=a(e),V=o(e,"P",{"data-svelte-h":!0}),r(V)!=="svelte-2fnzuy"&&(V.textContent=si),st=a(e),N=o(e,"P",{"data-svelte-h":!0}),r(N)!=="svelte-1eb4wcp"&&(N.textContent=ai),at=a(e),W=o(e,"P",{"data-svelte-h":!0}),r(W)!=="svelte-6frd8j"&&(W.innerHTML=li),lt=a(e),Y=o(e,"P",{"data-svelte-h":!0}),r(Y)!=="svelte-3g7k5p"&&(Y.textContent=oi),ot=a(e),X=o(e,"P",{"data-svelte-h":!0}),r(X)!=="svelte-83hxkb"&&(X.textContent=ri),rt=a(e),J=o(e,"P",{"data-svelte-h":!0}),r(J)!=="svelte-17n37z8"&&(J.textContent=fi),ft=a(e),K=o(e,"P",{"data-svelte-h":!0}),r(K)!=="svelte-1wda5f9"&&(K.innerHTML=ui),ut=a(e),Q=o(e,"P",{"data-svelte-h":!0}),r(Q)!=="svelte-g2n3xy"&&(Q.innerHTML=di),dt=a(e),Z=o(e,"P",{"data-svelte-h":!0}),r(Z)!=="svelte-19tascd"&&(Z.textContent=pi),pt=a(e),ee=o(e,"P",{"data-svelte-h":!0}),r(ee)!=="svelte-4twp6v"&&(ee.textContent=hi),ht=a(e),te=o(e,"P",{"data-svelte-h":!0}),r(te)!=="svelte-1kvno7h"&&(te.textContent=mi),mt=a(e),ie=o(e,"P",{"data-svelte-h":!0}),r(ie)!=="svelte-npu7j4"&&(ie.innerHTML=gi),gt=a(e),ne=o(e,"P",{"data-svelte-h":!0}),r(ne)!=="svelte-5uxpv9"&&(ne.innerHTML=ci),ct=a(e),se=o(e,"P",{"data-svelte-h":!0}),r(se)!=="svelte-1fih4h4"&&(se.textContent=vi),vt=a(e),ae=o(e,"P",{"data-svelte-h":!0}),r(ae)!=="svelte-4z7557"&&(ae.textContent=xi),xt=a(e),he(le.$$.fragment,e),wt=a(e),oe=o(e,"P",{"data-svelte-h":!0}),r(oe)!=="svelte-i32k1d"&&(oe.textContent=wi),yt=a(e),re=o(e,"P",{"data-svelte-h":!0}),r(re)!=="svelte-150c44o"&&(re.textContent=yi),bt=a(e),fe=o(e,"UL",{"data-svelte-h":!0}),r(fe)!=="svelte-10giegr"&&(fe.innerHTML=bi),Tt=a(e),he(ue.$$.fragment,e),Ct=a(e),de=o(e,"UL",{"data-svelte-h":!0}),r(de)!=="svelte-b68cct"&&(de.innerHTML=Ti),_t=a(e),ye=o(e,"P",{}),Ci(ye).forEach(i),this.h()},h(){_i(f,"name","hf:doc:metadata"),_i(f,"content",Si)},m(e,t){ki(document.head,f),n(e,be,t),n(e,we,t),n(e,Te,t),me(u,e,t),n(e,Ce,t),n(e,d,t),n(e,_e,t),n(e,p,t),n(e,Le,t),me(h,e,t),n(e,Me,t),n(e,m,t),n(e,Pe,t),n(e,g,t),n(e,He,t),n(e,c,t),n(e,De,t),n(e,v,t),n(e,$e,t),n(e,x,t),n(e,ke,t),n(e,w,t),n(e,Ie,t),n(e,y,t),n(e,Se,t),n(e,b,t),n(e,Ae,t),n(e,T,t),n(e,qe,t),me(C,e,t),n(e,je,t),n(e,_,t),n(e,Ge,t),n(e,L,t),n(e,ze,t),n(e,M,t),n(e,Ee,t),n(e,P,t),n(e,Re,t),n(e,H,t),n(e,Ue,t),n(e,D,t),n(e,Be,t),n(e,$,t),n(e,Fe,t),n(e,k,t),n(e,Oe,t),n(e,I,t),n(e,Ve,t),me(S,e,t),n(e,Ne,t),n(e,A,t),n(e,We,t),n(e,q,t),n(e,Ye,t),n(e,j,t),n(e,Xe,t),n(e,G,t),n(e,Je,t),n(e,z,t),n(e,Ke,t),n(e,E,t),n(e,Qe,t),n(e,R,t),n(e,Ze,t),n(e,U,t),n(e,et,t),n(e,B,t),n(e,tt,t),n(e,F,t),n(e,it,t),n(e,O,t),n(e,nt,t),n(e,V,t),n(e,st,t),n(e,N,t),n(e,at,t),n(e,W,t),n(e,lt,t),n(e,Y,t),n(e,ot,t),n(e,X,t),n(e,rt,t),n(e,J,t),n(e,ft,t),n(e,K,t),n(e,ut,t),n(e,Q,t),n(e,dt,t),n(e,Z,t),n(e,pt,t),n(e,ee,t),n(e,ht,t),n(e,te,t),n(e,mt,t),n(e,ie,t),n(e,gt,t),n(e,ne,t),n(e,ct,t),n(e,se,t),n(e,vt,t),n(e,ae,t),n(e,xt,t),me(le,e,t),n(e,wt,t),n(e,oe,t),n(e,yt,t),n(e,re,t),n(e,bt,t),n(e,fe,t),n(e,Tt,t),me(ue,e,t),n(e,Ct,t),n(e,de,t),n(e,_t,t),n(e,ye,t),Lt=!0},p:Mi,i(e){Lt||(ge(u.$$.fragment,e),ge(h.$$.fragment,e),ge(C.$$.fragment,e),ge(S.$$.fragment,e),ge(le.$$.fragment,e),ge(ue.$$.fragment,e),Lt=!0)},o(e){ce(u.$$.fragment,e),ce(h.$$.fragment,e),ce(C.$$.fragment,e),ce(S.$$.fragment,e),ce(le.$$.fragment,e),ce(ue.$$.fragment,e),Lt=!1},d(e){e&&(i(be),i(we),i(Te),i(Ce),i(d),i(_e),i(p),i(Le),i(Me),i(m),i(Pe),i(g),i(He),i(c),i(De),i(v),i($e),i(x),i(ke),i(w),i(Ie),i(y),i(Se),i(b),i(Ae),i(T),i(qe),i(je),i(_),i(Ge),i(L),i(ze),i(M),i(Ee),i(P),i(Re),i(H),i(Ue),i(D),i(Be),i($),i(Fe),i(k),i(Oe),i(I),i(Ve),i(Ne),i(A),i(We),i(q),i(Ye),i(j),i(Xe),i(G),i(Je),i(z),i(Ke),i(E),i(Qe),i(R),i(Ze),i(U),i(et),i(B),i(tt),i(F),i(it),i(O),i(nt),i(V),i(st),i(N),i(at),i(W),i(lt),i(Y),i(ot),i(X),i(rt),i(J),i(ft),i(K),i(ut),i(Q),i(dt),i(Z),i(pt),i(ee),i(ht),i(te),i(mt),i(ie),i(gt),i(ne),i(ct),i(se),i(vt),i(ae),i(xt),i(wt),i(oe),i(yt),i(re),i(bt),i(fe),i(Tt),i(Ct),i(de),i(_t),i(ye)),i(f),ve(u,e),ve(h,e),ve(C,e),ve(S,e),ve(le,e),ve(ue,e)}}}const Si='{"title":"Synthetic Data Generation with Diffusion Models","local":"synthetic-data-generation-with-diffusion-models","sections":[{"title":"Recap of the Diffusion Models","local":"recap-of-the-diffusion-models","sections":[],"depth":2},{"title":"Text-To-Image Diffusion Model: Stable Diffusion","local":"text-to-image-diffusion-model-stable-diffusion","sections":[],"depth":2},{"title":"Approaches to Synthetic Data Generation","local":"approaches-to-synthetic-data-generation","sections":[],"depth":2},{"title":"Real-world Examples of Using Diffusion Models for Dataset Generation","local":"real-world-examples-of-using-diffusion-models-for-dataset-generation","sections":[],"depth":2},{"title":"Further reading about Stable Diffusion","local":"further-reading-about-stable-diffusion","sections":[],"depth":2}],"depth":1}';function Ai(Mt){return Pi(()=>{new URLSearchParams(window.location.search).get("fw")}),[]}class zi extends Hi{constructor(f){super(),Di(this,f,Ai,Ii,Li,{})}}export{zi as component};
